@@ -1,7 +1,12 @@
 """PCA9685 pwm driver."""
-import board
 import busio
 import adafruit_pca9685
+from adafruit_blinka.agnostic import board_id
+try:
+    import board
+except NotImplementedError:
+    # Defer raising error to initialization of Pca9685Driver class
+    board = None
 
 from pwmled.driver import Driver
 
@@ -21,6 +26,12 @@ class Pca9685Driver(Driver):
         """
         super().__init__(pins, self.RESOLUTION, freq)
 
+        # Raise error if board couldn't be imported
+        if not board:
+            if not board_id:
+                raise NotImplementedError('Board is unknown')
+            raise NotImplementedError(f'Board "{board_id}" is not supported')
+
         i2c = busio.I2C(board.SCL, board.SDA)
         self._device = adafruit_pca9685.PCA9685(i2c, address=address)
         self._device.frequency = self._freq
@@ -31,9 +42,10 @@ class Pca9685Driver(Driver):
 
         :param raw_values: Raw values to set (0-65535).
         """
-        for i in range(len(self._pins)):
-            channel = self._device.channels[self._pins[i]]
-            channel.duty_cycle = raw_values[i]
+        for pin, value in zip(self._pins, raw_values):
+            channel = self._device.channels[pin]
+            if channel.duty_cycle != value:
+                channel.duty_cycle = value
 
     def _stop(self):
         """Stop the driver and release resources."""
